@@ -14,6 +14,11 @@ url_paths = {
     "{0}/v1/registerjobdefinition": BatchResponse.dispatch,
     "{0}/v1/deregisterjobdefinition": BatchResponse.dispatch,
     "{0}/v1/describejobdefinitions": BatchResponse.dispatch,
+    "{0}/v1/createschedulingpolicy": BatchResponse.dispatch,
+    "{0}/v1/describeschedulingpolicies": BatchResponse.dispatch,
+    "{0}/v1/listschedulingpolicies": BatchResponse.dispatch,
+    "{0}/v1/deleteschedulingpolicy": BatchResponse.dispatch,
+    "{0}/v1/updateschedulingpolicy": BatchResponse.dispatch,
     "{0}/v1/submitjob": BatchResponse.dispatch,
     "{0}/v1/describejobs": BatchResponse.dispatch,
     "{0}/v1/listjobs": BatchResponse.dispatch,
