@@ -1,15 +1,15 @@
-import boto3
-
-from moto import mock_autoscaling, mock_elb, mock_ec2
-from .utils import setup_networking
-from tests import EXAMPLE_AMI_ID
 from unittest import TestCase
 from uuid import uuid4
 
+import boto3
 
-@mock_autoscaling
-@mock_ec2
-@mock_elb
+from moto import mock_aws
+from tests import EXAMPLE_AMI_ID
+
+from .utils import setup_networking
+
+
+@mock_aws
 class TestAutoScalingELB(TestCase):
     def setUp(self):
         self.mocked_networking = setup_networking()
@@ -264,9 +264,7 @@ class TestAutoScalingELB(TestCase):
         assert scheduled_action_1["ScheduledActionName"] == "my-scheduled-action"
 
 
-@mock_autoscaling
-@mock_elb
-@mock_ec2
+@mock_aws
 class TestAutoScalingInstances(TestCase):
     def setUp(self) -> None:
         self.mocked_networking = setup_networking()
@@ -331,6 +329,8 @@ class TestAutoScalingInstances(TestCase):
             ShouldDecrementDesiredCapacity=True,
         )
         assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+        assert response["Activities"][0]["AutoScalingGroupName"] == self.asg_name
+        assert instance_to_detach in response["Activities"][0]["Description"]
 
         response = self.as_client.describe_auto_scaling_groups(
             AutoScalingGroupNames=[self.asg_name]
@@ -552,6 +552,8 @@ class TestAutoScalingInstances(TestCase):
             ShouldDecrementDesiredCapacity=True,
         )
         assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+        assert response["Activity"]["StatusCode"] == "InProgress"
+        assert response["Activity"]["AutoScalingGroupName"] == self.asg_name
 
         # AWS still decrements desired capacity ASG if requested, even if the terminated instance is in standby
         response = self.as_client.describe_auto_scaling_groups(
@@ -652,6 +654,8 @@ class TestAutoScalingInstances(TestCase):
             ShouldDecrementDesiredCapacity=False,
         )
         assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+        assert response["Activities"][0]["StatusCode"] == "InProgress"
+        assert response["Activities"][0]["AutoScalingGroupName"] == self.asg_name
 
         response = self.as_client.describe_auto_scaling_groups(
             AutoScalingGroupNames=[self.asg_name]
@@ -781,6 +785,7 @@ class TestAutoScalingInstances(TestCase):
             InstanceIds=[instance_to_standby_exit_standby],
         )
         assert response["ResponseMetadata"]["HTTPStatusCode"] == 200
+        assert response["Activities"][0]["StatusCode"] == "PreInService"
 
         response = self.as_client.describe_auto_scaling_groups(
             AutoScalingGroupNames=[self.asg_name]
@@ -807,9 +812,7 @@ class TestAutoScalingInstances(TestCase):
         ]
 
 
-@mock_autoscaling
-@mock_elb
-@mock_ec2
+@mock_aws
 class TestAutoScalingInstancesProtected(TestCase):
     def setUp(self) -> None:
         self.mocked_networking = setup_networking()
@@ -884,9 +887,7 @@ class TestAutoScalingInstancesProtected(TestCase):
         assert len(list(response["LoadBalancerDescriptions"][0]["Instances"])) == 3
 
 
-@mock_autoscaling
-@mock_ec2
-@mock_elb
+@mock_aws
 class TestAutoScalingTerminateInstances(TestCase):
     def setUp(self) -> None:
         self.mocked_networking = setup_networking()
