@@ -6,10 +6,11 @@ from typing import Any, List, Optional
 import pytest
 
 from moto.autoscaling.models import AutoScalingBackend
-from moto.core import DEFAULT_ACCOUNT_ID, BackendDict, BaseBackend
-from moto.core.base_backend import AccountSpecificBackend
+from moto.core import DEFAULT_ACCOUNT_ID
+from moto.core.base_backend import AccountSpecificBackend, BackendDict, BaseBackend
 from moto.ec2.models import EC2Backend
 from moto.elbv2.models import ELBv2Backend
+from moto.utilities.utils import PARTITION_NAMES
 
 
 class ExampleBackend(BaseBackend):
@@ -35,7 +36,7 @@ def test_backend_dict_does_not_contain_unknown_regions() -> None:
 def test_backend_dict_fails_when_retrieving_unknown_regions() -> None:
     backend_dict = BackendDict(ExampleBackend, "ec2")
     with pytest.raises(KeyError):
-        backend_dict["account"]["mars-south-1"]  # pylint: disable=pointless-statement
+        backend_dict["account"]["mars-south-1"]
 
 
 def test_backend_dict_can_retrieve_for_specific_account() -> None:
@@ -63,7 +64,7 @@ def test_backend_dict_can_ignore_boto3_regions() -> None:
 
 def test_backend_dict_can_specify_additional_regions() -> None:
     backend_dict = BackendDict(
-        ExampleBackend, "ec2", additional_regions=["region1", "global"]
+        ExampleBackend, "ec2", additional_regions=["region1", "global", "aws"]
     )["123456"]
     assert isinstance(backend_dict["us-east-1"], ExampleBackend)
     assert isinstance(backend_dict["region1"], ExampleBackend)
@@ -156,106 +157,56 @@ def _create_asb(
 def test_multiple_backends_cache_behaviour() -> None:
     ec2 = BackendDict(EC2Backend, "ec2")
     ec2_useast1 = ec2[DEFAULT_ACCOUNT_ID]["us-east-1"]
-    assert type(ec2_useast1) == EC2Backend
+    assert type(ec2_useast1) is EC2Backend
 
     autoscaling = BackendDict(AutoScalingBackend, "autoscaling")
     as_1 = autoscaling[DEFAULT_ACCOUNT_ID]["us-east-1"]
-    assert type(as_1) == AutoScalingBackend
+    assert type(as_1) is AutoScalingBackend
 
     from moto.elbv2 import elbv2_backends
 
     elbv2_useast = elbv2_backends["00000000"]["us-east-1"]
-    assert type(elbv2_useast) == ELBv2Backend
+    assert type(elbv2_useast) is ELBv2Backend
     elbv2_useast2 = elbv2_backends[DEFAULT_ACCOUNT_ID]["us-east-2"]
-    assert type(elbv2_useast2) == ELBv2Backend
+    assert type(elbv2_useast2) is ELBv2Backend
 
     ec2_useast1 = ec2[DEFAULT_ACCOUNT_ID]["us-east-1"]
-    assert type(ec2_useast1) == EC2Backend
+    assert type(ec2_useast1) is EC2Backend
     ec2_useast2 = ec2[DEFAULT_ACCOUNT_ID]["us-east-2"]
-    assert type(ec2_useast2) == EC2Backend
+    assert type(ec2_useast2) is EC2Backend
 
     as_1 = autoscaling[DEFAULT_ACCOUNT_ID]["us-east-1"]
-    assert type(as_1) == AutoScalingBackend
+    assert type(as_1) is AutoScalingBackend
 
 
-def test_backenddict_cache_hits_and_misses() -> None:
-    backend = BackendDict(ExampleBackend, "ebs")
-    backend.__getitem__.cache_clear()
+def test_global_region_defaults_to_aws() -> None:
+    s3 = BackendDict(ExampleBackend, "s3", additional_regions=PARTITION_NAMES)
 
-    assert backend.__getitem__.cache_info().hits == 0
-    assert backend.__getitem__.cache_info().misses == 0
-    assert backend.__getitem__.cache_info().currsize == 0
+    # Internally we use 'aws' as the S3 region
+    s3_aws = s3[DEFAULT_ACCOUNT_ID]["aws"]
+    assert isinstance(s3_aws, ExampleBackend)
 
-    # Create + Retrieve an account - verify it is stored in cache
-    accnt_1 = backend["accnt1"]
-    assert accnt_1.account_id == "accnt1"
+    # But users may still call this 'global'
+    # Ensure that we're getting the backend
+    s3_global = s3[DEFAULT_ACCOUNT_ID]["global"]
+    assert s3_global == s3_aws
 
-    assert backend.__getitem__.cache_info().hits == 0
-    assert backend.__getitem__.cache_info().misses == 1
-    assert backend.__getitem__.cache_info().currsize == 1
+    # Changes to S3AWS should show up in global
+    s3_aws.var = "test"  # type: ignore[attr-defined]
+    assert s3_global.var == "test"  # type: ignore[attr-defined]
 
-    # Creating + Retrieving a second account
-    accnt_2 = backend["accnt2"]
-    assert accnt_2.account_id == "accnt2"
-
-    assert backend.__getitem__.cache_info().hits == 0
-    assert backend.__getitem__.cache_info().misses == 2
-    assert backend.__getitem__.cache_info().currsize == 2
-
-    # Retrieving the first account from cache
-    accnt_1_again = backend["accnt1"]
-    assert accnt_1_again.account_id == "accnt1"
-
-    assert backend.__getitem__.cache_info().hits == 1
-    assert backend.__getitem__.cache_info().misses == 2
-    assert backend.__getitem__.cache_info().currsize == 2
-
-    # Retrieving the second account from cache
-    accnt_2_again = backend["accnt2"]
-    assert accnt_2_again.account_id == "accnt2"
-
-    assert backend.__getitem__.cache_info().hits == 2
-    assert backend.__getitem__.cache_info().misses == 2
-    assert backend.__getitem__.cache_info().currsize == 2
+    assert "aws" in s3[DEFAULT_ACCOUNT_ID]
+    assert "global" in s3[DEFAULT_ACCOUNT_ID]
 
 
-def test_asb_cache_hits_and_misses() -> None:
-    backend = BackendDict(ExampleBackend, "ebs")
-    acb = backend["accnt_id"]
-    acb.__getitem__.cache_clear()
+def test_iterate_backend_dict() -> None:
+    ec2 = BackendDict(EC2Backend, "ec2")
+    _ = ec2[DEFAULT_ACCOUNT_ID]["us-east-1"]
+    _ = ec2[DEFAULT_ACCOUNT_ID]["us-east-2"]
 
-    assert acb.__getitem__.cache_info().hits == 0
-    assert acb.__getitem__.cache_info().misses == 0
-    assert acb.__getitem__.cache_info().currsize == 0
-
-    # Create + Retrieve an account - verify it is stored in cache
-    region_1 = acb["us-east-1"]
-    assert region_1.region_name == "us-east-1"
-
-    assert acb.__getitem__.cache_info().hits == 0
-    assert acb.__getitem__.cache_info().misses == 1
-    assert acb.__getitem__.cache_info().currsize == 1
-
-    # Creating + Retrieving a second account
-    region_2 = acb["us-east-2"]
-    assert region_2.region_name == "us-east-2"
-
-    assert acb.__getitem__.cache_info().hits == 0
-    assert acb.__getitem__.cache_info().misses == 2
-    assert acb.__getitem__.cache_info().currsize == 2
-
-    # Retrieving the first account from cache
-    region_1_again = acb["us-east-1"]
-    assert region_1_again.region_name == "us-east-1"
-
-    assert acb.__getitem__.cache_info().hits == 1
-    assert acb.__getitem__.cache_info().misses == 2
-    assert acb.__getitem__.cache_info().currsize == 2
-
-    # Retrieving the second account from cache
-    region_2_again = acb["us-east-2"]
-    assert region_2_again.region_name == "us-east-2"
-
-    assert acb.__getitem__.cache_info().hits == 2
-    assert acb.__getitem__.cache_info().misses == 2
-    assert acb.__getitem__.cache_info().currsize == 2
+    regions = {"us-east-1", "us-east-2"}
+    for account, region, backend in ec2.iter_backends():
+        assert isinstance(backend, EC2Backend)
+        assert region in regions
+        regions.remove(region)
+        assert account == DEFAULT_ACCOUNT_ID
