@@ -1,6 +1,6 @@
 import boto3
 
-from moto import mock_ec2instanceconnect
+from moto import mock_aws
 
 pubkey = """ssh-rsa
 AAAAB3NzaC1yc2EAAAADAQABAAABAQDV5+voluw2zmzqpqCAqtsyoP01TQ8Ydx1eS1yD6wUsHcPqMIqpo57YxiC8XPwrdeKQ6GG6MC3bHsgXoPypGP0LyixbiuLTU31DnnqorcHt4bWs6rQa7dK2pCCflz2fhYRt5ZjqSNsAKivIbqkH66JozN0SySIka3kEV79GdB0BicioKeEJlCwM9vvxafyzjWf/z8E0lh4ni3vkLpIVJ0t5l+Qd9QMJrT6Is0SCQPVagTYZoi8+fWDoGsBa8vyRwDjEzBl28ZplKh9tSyDkRIYszWTpmK8qHiqjLYZBfAxXjGJbEYL1iig4ZxvbYzKEiKSBi1ZMW9iWjHfZDZuxXAmB
@@ -8,7 +8,7 @@ example
 """
 
 
-@mock_ec2instanceconnect
+@mock_aws
 def test_send_ssh_public_key():
     client = boto3.client("ec2-instance-connect", region_name="us-east-1")
     fake_request_id = "example-2a47-4c91-9700-e37e85162cb6"
