@@ -1,28 +1,32 @@
 import json
+from time import sleep
 from unittest import SkipTest
 from unittest.mock import patch
+from uuid import uuid4
 
 import boto3
 import pytest
 from botocore.client import ClientError
 
-from moto import mock_s3, settings
+from moto import mock_aws, settings
 from moto.core import DEFAULT_ACCOUNT_ID
 from moto.s3 import s3_backends
 from moto.s3.models import FakeBucket
 from moto.s3.responses import DEFAULT_REGION_NAME
+from tests.test_s3 import empty_bucket, s3_aws_verified
 
 
-@mock_s3
+@mock_aws
 def test_put_bucket_logging():
     s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
+    wrong_region_client = boto3.client("s3", region_name="us-west-2")
     bucket_name = "mybucket"
     log_bucket = "logbucket"
     wrong_region_bucket = "wrongregionlogbucket"
     s3_client.create_bucket(Bucket=bucket_name)
     # Adding the ACL for log-delivery later...
     s3_client.create_bucket(Bucket=log_bucket)
-    s3_client.create_bucket(
+    wrong_region_client.create_bucket(
         Bucket=wrong_region_bucket,
         CreateBucketConfiguration={"LocationConstraint": "us-west-2"},
     )
@@ -196,7 +200,7 @@ def test_put_bucket_logging():
     assert err.value.response["Error"]["Code"] == "MalformedXML"
 
 
-@mock_s3
+@mock_aws
 def test_log_file_is_created():
     # Create necessary buckets
     s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
@@ -270,7 +274,7 @@ def test_log_file_is_created():
     assert any(c for c in contents if "REST.PUT.BUCKET" in c)
 
 
-@mock_s3
+@mock_aws
 def test_invalid_bucket_logging_when_permissions_are_false():
     if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Can't patch permission logic in ServerMode")
@@ -280,10 +284,14 @@ def test_invalid_bucket_logging_when_permissions_are_false():
     log_bucket = "logbucket"
     s3_client.create_bucket(Bucket=bucket_name)
     s3_client.create_bucket(Bucket=log_bucket)
-    with patch(
-        "moto.s3.models.FakeBucket._log_permissions_enabled_policy", return_value=False
-    ), patch(
-        "moto.s3.models.FakeBucket._log_permissions_enabled_acl", return_value=False
+    with (
+        patch(
+            "moto.s3.models.FakeBucket._log_permissions_enabled_policy",
+            return_value=False,
+        ),
+        patch(
+            "moto.s3.models.FakeBucket._log_permissions_enabled_acl", return_value=False
+        ),
     ):
         with pytest.raises(ClientError) as err:
             s3_client.put_bucket_logging(
@@ -296,7 +304,7 @@ def test_invalid_bucket_logging_when_permissions_are_false():
         assert "log-delivery" in err.value.response["Error"]["Message"]
 
 
-@mock_s3
+@mock_aws
 def test_valid_bucket_logging_when_permissions_are_true():
     if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Can't patch permission logic in ServerMode")
@@ -306,10 +314,14 @@ def test_valid_bucket_logging_when_permissions_are_true():
     log_bucket = "logbucket"
     s3_client.create_bucket(Bucket=bucket_name)
     s3_client.create_bucket(Bucket=log_bucket)
-    with patch(
-        "moto.s3.models.FakeBucket._log_permissions_enabled_policy", return_value=True
-    ), patch(
-        "moto.s3.models.FakeBucket._log_permissions_enabled_acl", return_value=True
+    with (
+        patch(
+            "moto.s3.models.FakeBucket._log_permissions_enabled_policy",
+            return_value=True,
+        ),
+        patch(
+            "moto.s3.models.FakeBucket._log_permissions_enabled_acl", return_value=True
+        ),
     ):
         s3_client.put_bucket_logging(
             Bucket=bucket_name,
@@ -325,7 +337,7 @@ def test_valid_bucket_logging_when_permissions_are_true():
         assert result["LoggingEnabled"]["TargetPrefix"] == f"{bucket_name}/"
 
 
-@mock_s3
+@mock_aws
 def test_bucket_policy_not_set():
     if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Can't patch permission logic in ServerMode")
@@ -345,7 +357,7 @@ def test_bucket_policy_not_set():
     )
 
 
-@mock_s3
+@mock_aws
 def test_bucket_policy_principal():
     if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Can't patch permission logic in ServerMode")
@@ -400,7 +412,7 @@ def test_bucket_policy_principal():
     )
 
 
-@mock_s3
+@mock_aws
 def test_bucket_policy_effect():
     if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Can't patch permission logic in ServerMode")
@@ -454,7 +466,7 @@ def test_bucket_policy_effect():
     )
 
 
-@mock_s3
+@mock_aws
 def test_bucket_policy_action():
     if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Can't patch permission logic in ServerMode")
@@ -506,7 +518,7 @@ def test_bucket_policy_action():
     )
 
 
-@mock_s3
+@mock_aws
 def test_bucket_policy_resource():
     if not settings.TEST_DECORATOR_MODE:
         raise SkipTest("Can't patch permission logic in ServerMode")
@@ -587,3 +599,86 @@ def test_bucket_policy_resource():
     assert FakeBucket._log_permissions_enabled_policy(
         target_bucket=log_bucket_obj, target_prefix="prefix"
     )
+
+
+@s3_aws_verified
+@pytest.mark.aws_verified
+def test_put_logging_w_bucket_policy_no_prefix(bucket_name=None):
+    s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
+
+    log_bucket_name = f"{uuid4()}"
+    s3_client.create_bucket(Bucket=log_bucket_name)
+    bucket_policy = {
+        "Version": "2012-10-17",
+        "Statement": [
+            {
+                "Sid": "S3ServerAccessLogsPolicy",
+                "Effect": "Allow",
+                "Principal": {"Service": "logging.s3.amazonaws.com"},
+                "Action": ["s3:PutObject"],
+                "Resource": f"arn:aws:s3:::{log_bucket_name}/*",
+            }
+        ],
+    }
+    s3_client.put_bucket_policy(
+        Bucket=log_bucket_name, Policy=json.dumps(bucket_policy)
+    )
+    s3_client.put_bucket_logging(
+        Bucket=bucket_name,
+        BucketLoggingStatus={
+            "LoggingEnabled": {"TargetBucket": log_bucket_name, "TargetPrefix": ""}
+        },
+    )
+    result = s3_client.get_bucket_logging(Bucket=bucket_name)
+    # Logging Config is not immediately available
+    for _ in range(5):
+        if "LoggingEnabled" not in result:
+            sleep(1)
+            result = s3_client.get_bucket_logging(Bucket=bucket_name)
+    assert result["LoggingEnabled"]["TargetBucket"] == log_bucket_name
+    assert result["LoggingEnabled"]["TargetPrefix"] == ""
+
+    empty_bucket(s3_client, log_bucket_name)
+    s3_client.delete_bucket(Bucket=log_bucket_name)
+
+
+@s3_aws_verified
+@pytest.mark.aws_verified
+def test_put_logging_w_bucket_policy_w_prefix(bucket_name=None):
+    s3_client = boto3.client("s3", region_name=DEFAULT_REGION_NAME)
+
+    log_bucket_name = f"{uuid4()}"
+    s3_client.create_bucket(Bucket=log_bucket_name)
+    prefix = "some-prefix"
+    bucket_policy = {
+        "Version": "2012-10-17",
+        "Statement": [
+            {
+                "Sid": "S3ServerAccessLogsPolicy",
+                "Effect": "Allow",
+                "Principal": {"Service": "logging.s3.amazonaws.com"},
+                "Action": ["s3:PutObject"],
+                "Resource": f"arn:aws:s3:::{log_bucket_name}/{prefix}*",
+            }
+        ],
+    }
+    s3_client.put_bucket_policy(
+        Bucket=log_bucket_name, Policy=json.dumps(bucket_policy)
+    )
+    s3_client.put_bucket_logging(
+        Bucket=bucket_name,
+        BucketLoggingStatus={
+            "LoggingEnabled": {"TargetBucket": log_bucket_name, "TargetPrefix": prefix}
+        },
+    )
+    result = s3_client.get_bucket_logging(Bucket=bucket_name)
+    # Logging Config is not immediately available
+    for _ in range(5):
+        if "LoggingEnabled" not in result:
+            sleep(1)
+            result = s3_client.get_bucket_logging(Bucket=bucket_name)
+    assert result["LoggingEnabled"]["TargetBucket"] == log_bucket_name
+    assert result["LoggingEnabled"]["TargetPrefix"] == prefix
+
+    empty_bucket(s3_client, log_bucket_name)
+    s3_client.delete_bucket(Bucket=log_bucket_name)
