@@ -4,11 +4,11 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_sns, mock_sqs
+from moto import mock_aws
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
 
 
-@mock_sns
+@mock_aws
 def test_publish_batch_unknown_topic():
     client = boto3.client("sns", region_name="us-east-1")
     with pytest.raises(ClientError) as exc:
@@ -21,7 +21,7 @@ def test_publish_batch_unknown_topic():
     assert err["Message"] == "Topic does not exist"
 
 
-@mock_sns
+@mock_aws
 def test_publish_batch_too_many_items():
     client = boto3.client("sns", region_name="eu-north-1")
     topic = client.create_topic(Name="some-topic")
@@ -38,7 +38,7 @@ def test_publish_batch_too_many_items():
     assert err["Message"] == "The batch request contains more entries than permissible."
 
 
-@mock_sns
+@mock_aws
 def test_publish_batch_non_unique_ids():
     client = boto3.client("sns", region_name="us-west-2")
     topic = client.create_topic(Name="some-topic")
@@ -57,7 +57,7 @@ def test_publish_batch_non_unique_ids():
     )
 
 
-@mock_sns
+@mock_aws
 def test_publish_batch_fifo_without_message_group_id():
     client = boto3.client("sns", region_name="us-east-1")
     topic = client.create_topic(
@@ -77,7 +77,7 @@ def test_publish_batch_fifo_without_message_group_id():
     )
 
 
-@mock_sns
+@mock_aws
 def test_publish_batch_standard_with_message_group_id():
     client = boto3.client("sns", region_name="us-east-1")
     topic_arn = client.create_topic(Name="standard_topic")["TopicArn"]
@@ -105,8 +105,7 @@ def test_publish_batch_standard_with_message_group_id():
     }
 
 
-@mock_sns
-@mock_sqs
+@mock_aws
 def test_publish_batch_to_sqs():
     client = boto3.client("sns", region_name="us-east-1")
     topic_arn = client.create_topic(Name="standard_topic")["TopicArn"]
@@ -146,8 +145,7 @@ def test_publish_batch_to_sqs():
     ) in messages
 
 
-@mock_sqs
-@mock_sns
+@mock_aws
 def test_publish_batch_to_sqs_raw():
     client = boto3.client("sns", region_name="us-east-1")
     topic_arn = client.create_topic(Name="standard_topic")["TopicArn"]
@@ -182,3 +180,98 @@ def test_publish_batch_to_sqs_raw():
 
     assert ("foo", None) in messages
     assert ("bar", {"a": {"StringValue": "v", "DataType": "String"}}) in messages
+
+
+@mock_aws
+def test_publish_with_with_message_structure_json():
+    sns = boto3.client("sns", region_name="us-east-1")
+
+    topic = sns.create_topic(Name="some-topic")
+
+    sqs = boto3.resource("sqs", region_name="us-east-1")
+    queue = sqs.create_queue(QueueName="test-queue")
+
+    sns.subscribe(
+        TopicArn=topic["TopicArn"],
+        Protocol="sqs",
+        Endpoint=queue.attributes["QueueArn"],
+    )
+
+    entries = [
+        {
+            "Id": "no-message-structure",
+            "Message": "no-message-structure",
+        },
+        {
+            "Id": "json-message-structure",
+            "Message": json.dumps(
+                {
+                    "default": "default-message",
+                    "sqs": "queue-message",
+                }
+            ),
+            "MessageStructure": "json",
+        },
+        {
+            "Id": "json-message-structure-fallback-to-default",
+            "Message": json.dumps(
+                {
+                    "default": "default-message",
+                    "email": "email-message",
+                }
+            ),
+            "MessageStructure": "json",
+        },
+    ]
+
+    sns.publish_batch(
+        TopicArn=topic["TopicArn"],
+        PublishBatchRequestEntries=entries,
+    )
+
+    queue_messages = queue.receive_messages(MaxNumberOfMessages=10)
+
+    assert len(queue_messages) == 3
+
+    first_queue_message = json.loads(queue_messages[0].body)
+    assert first_queue_message["Message"] == "no-message-structure"
+
+    second_queue_message = json.loads(queue_messages[1].body)
+    assert second_queue_message["Message"] == "queue-message"
+
+    third_queue_message = json.loads(queue_messages[2].body)
+    assert third_queue_message["Message"] == "default-message"
+
+
+@mock_aws
+def test_publish_with_upper_cased_message_attributes():
+    sns = boto3.client("sns", "us-east-1")
+    sqs = boto3.resource("sqs", "us-east-1")
+
+    topic_arn = sns.create_topic(Name="topic")["TopicArn"]
+    queue = sqs.create_queue(QueueName="queue")
+    queue_arn = sqs.meta.client.get_queue_attributes(
+        QueueUrl=queue.url, AttributeNames=["QueueArn"]
+    )["Attributes"]["QueueArn"]
+
+    sns.subscribe(TopicArn=topic_arn, Protocol="sqs", Endpoint=queue_arn)
+
+    sns.publish_batch(
+        TopicArn=topic_arn,
+        PublishBatchRequestEntries=[
+            {
+                "Id": "some id",
+                "Message": json.dumps({"type": "test"}),
+                "MessageAttributes": {
+                    "SomeCamelCaseAttr": {"DataType": "String", "StringValue": "value"}
+                },
+            }
+        ],
+    )
+
+    msg = queue.receive_messages()[0]
+    body = json.loads(msg.body)
+
+    assert body["MessageAttributes"] == {
+        "SomeCamelCaseAttr": {"Type": "String", "Value": "value"}
+    }
