@@ -1,11 +1,10 @@
-"""Test different server responses."""
 import json
 
 import moto.server as server
-from moto import mock_textract
+from moto import mock_aws
 
 
-@mock_textract
+@mock_aws
 def test_textract_start_text_detection():
     backend = server.create_backend_app("textract")
     test_client = backend.test_client()
@@ -23,7 +22,7 @@ def test_textract_start_text_detection():
     assert isinstance(data["JobId"], str)
 
 
-@mock_textract
+@mock_aws
 def test_detect_document_text():
     backend = server.create_backend_app("textract")
     test_client = backend.test_client()
@@ -39,7 +38,7 @@ def test_detect_document_text():
     assert isinstance(data["Blocks"], list)
 
 
-@mock_textract
+@mock_aws
 def test_textract_start_text_detection_without_document_location():
     backend = server.create_backend_app("textract")
     test_client = backend.test_client()
@@ -55,7 +54,7 @@ def test_textract_start_text_detection_without_document_location():
     )
 
 
-@mock_textract
+@mock_aws
 def test_textract_get_text_detection():
     backend = server.create_backend_app("textract")
     test_client = backend.test_client()
@@ -80,7 +79,7 @@ def test_textract_get_text_detection():
     assert data["JobStatus"] == "SUCCEEDED"
 
 
-@mock_textract
+@mock_aws
 def test_textract_get_text_detection_without_job_id():
     backend = server.create_backend_app("textract")
     test_client = backend.test_client()
@@ -94,3 +93,48 @@ def test_textract_get_text_detection_without_job_id():
     data = json.loads(resp.data.decode("utf-8"))
     assert data["__type"] == "InvalidJobIdException"
     assert data["message"] == "An invalid job identifier was passed."
+
+
+@mock_aws
+def test_textract_start_document_analysis():
+    backend = server.create_backend_app("textract")
+    test_client = backend.test_client()
+
+    headers = {"X-Amz-Target": "X-Amz-Target=Textract.StartDocumentAnalysis"}
+    request_body = {
+        "DocumentLocation": {
+            "S3Object": {"Bucket": "bucket", "Name": "name", "Version": "version"}
+        },
+        "FeatureTypes": ["TABLES", "FORMS"],
+    }
+
+    resp = test_client.post("/", headers=headers, json=request_body)
+    data = json.loads(resp.data.decode("utf-8"))
+    assert resp.status_code == 200
+    assert isinstance(data["JobId"], str)
+
+
+@mock_aws
+def test_textract_get_document_analysis():
+    backend = server.create_backend_app("textract")
+    test_client = backend.test_client()
+
+    headers = {"X-Amz-Target": "X-Amz-Target=Textract.StartDocumentAnalysis"}
+    request_body = {
+        "DocumentLocation": {
+            "S3Object": {"Bucket": "bucket", "Name": "name", "Version": "version"}
+        },
+        "FeatureTypes": ["TABLES", "FORMS"],
+    }
+
+    resp = test_client.post("/", headers=headers, json=request_body)
+    start_job_data = json.loads(resp.data.decode("utf-8"))
+
+    headers = {"X-Amz-Target": "X-Amz-Target=Textract.GetDocumentAnalysis"}
+    request_body = {
+        "JobId": start_job_data["JobId"],
+    }
+    resp = test_client.post("/", headers=headers, json=request_body)
+    assert resp.status_code == 200
+    data = json.loads(resp.data.decode("utf-8"))
+    assert data["JobStatus"] == "SUCCEEDED"
