@@ -5,14 +5,13 @@ import boto3
 import pytest
 from botocore.exceptions import ClientError
 
-from moto import mock_timestreamwrite, settings
+from moto import mock_aws, settings
 from moto.core import DEFAULT_ACCOUNT_ID as ACCOUNT_ID
-
-from . import timestreamwrite_aws_verified
+from tests import aws_verified
 
 
 @pytest.mark.aws_verified
-@timestreamwrite_aws_verified
+@aws_verified
 def test_create_table():
     ts = boto3.client("timestream-write", region_name="us-east-1")
     db_name = "db_" + str(uuid4())[0:6]
@@ -49,7 +48,7 @@ def test_create_table():
 
 
 @pytest.mark.aws_verified
-@timestreamwrite_aws_verified
+@aws_verified
 def test_create_table__with_magnetic_store_write_properties():
     ts = boto3.client("timestream-write", region_name="us-east-1")
     db_name = "db_" + str(uuid4())[0:6]
@@ -94,7 +93,7 @@ def test_create_table__with_magnetic_store_write_properties():
 
 
 @pytest.mark.aws_verified
-@timestreamwrite_aws_verified
+@aws_verified
 def test_create_table_without_retention_properties():
     ts = boto3.client("timestream-write", region_name="us-east-1")
     db_name = "db_" + str(uuid4())[0:6]
@@ -122,7 +121,7 @@ def test_create_table_without_retention_properties():
         ts.delete_database(DatabaseName=db_name)
 
 
-@mock_timestreamwrite
+@mock_aws
 def test_describe_table():
     ts = boto3.client("timestream-write", region_name="us-east-1")
     ts.create_database(DatabaseName="mydatabase")
@@ -150,7 +149,7 @@ def test_describe_table():
 
 
 @pytest.mark.aws_verified
-@timestreamwrite_aws_verified
+@aws_verified
 def test_describe_unknown_database():
     ts = boto3.client("timestream-write", region_name="us-east-1")
     db_name = "db_" + str(uuid4())[0:6]
@@ -167,7 +166,7 @@ def test_describe_unknown_database():
         ts.delete_database(DatabaseName=db_name)
 
 
-@mock_timestreamwrite
+@mock_aws
 def test_create_multiple_tables():
     ts = boto3.client("timestream-write", region_name="us-east-1")
     ts.create_database(DatabaseName="mydatabase")
@@ -199,7 +198,40 @@ def test_create_multiple_tables():
     assert {t["TableStatus"] for t in tables} == {"ACTIVE"}
 
 
-@mock_timestreamwrite
+@mock_aws
+def test_list_tables_without_database():
+    ts = boto3.client("timestream-write", region_name="us-east-1")
+    ts.create_database(DatabaseName="mydatabase")
+
+    for idx in range(0, 5):
+        ts.create_table(
+            DatabaseName="mydatabase",
+            TableName=f"mytable_{idx}",
+            RetentionProperties={
+                "MemoryStoreRetentionPeriodInHours": 7,
+                "MagneticStoreRetentionPeriodInDays": 42,
+            },
+        )
+
+    database = ts.describe_database(DatabaseName="mydatabase")["Database"]
+
+    assert database["TableCount"] == 5
+
+    # database_name is optional in api call
+    tables = ts.list_tables()["Tables"]
+    assert len(tables) == 5
+    assert {t["DatabaseName"] for t in tables} == {"mydatabase"}
+    assert {t["TableName"] for t in tables} == {
+        "mytable_0",
+        "mytable_1",
+        "mytable_2",
+        "mytable_3",
+        "mytable_4",
+    }
+    assert {t["TableStatus"] for t in tables} == {"ACTIVE"}
+
+
+@mock_aws
 def test_delete_table():
     ts = boto3.client("timestream-write", region_name="us-east-1")
     ts.create_database(DatabaseName="mydatabase")
@@ -224,7 +256,7 @@ def test_delete_table():
     assert {t["TableName"] for t in tables} == {"mytable_0", "mytable_2"}
 
 
-@mock_timestreamwrite
+@mock_aws
 def test_update_table():
     ts = boto3.client("timestream-write", region_name="us-east-1")
     ts.create_database(DatabaseName="mydatabase")
@@ -257,7 +289,7 @@ def test_update_table():
     }
 
 
-@mock_timestreamwrite
+@mock_aws
 def test_update_table__with_magnetic_store_write_properties():
     ts = boto3.client("timestream-write", region_name="us-east-1")
     ts.create_database(DatabaseName="mydatabase")
@@ -289,7 +321,7 @@ def test_update_table__with_magnetic_store_write_properties():
     }
 
 
-@mock_timestreamwrite
+@mock_aws
 def test_write_records():
     # The query-feature is not available at the moment,
     # so there's no way for us to verify writing records is successful
